@@ -16,6 +16,8 @@ use Mojo::Loader qw(load_class);
 #
 #    push @{$migrations}, {class => 'Daje::Workflow::Database', name => 'workflow', migration => 2};
 #
+#    push @{$migrations}, {file => '/home/user/schema/users.sql', name => 'users'};
+#
 #    Daje::Workflow::Database->new(
 #         pg            => $pg,
 #         migrations    => $migrations,
@@ -40,7 +42,7 @@ use Mojo::Loader qw(load_class);
 # janeskil1525 E<lt>janeskil1525@gmail.comE<gt>
 #
 
-our $VERSION = "0.16";
+our $VERSION = "0.18";
 
 has 'pg';
 has 'migrations';
@@ -49,10 +51,25 @@ sub migrate($self) {
 
     my $length = scalar @{$self->migrations};
     for (my $i = 0; $i < $length; $i++) {
-        my $cl = load_class @{$self->migrations}[$i]->{class};
-        $self->pg->migrations->name(@{$self->migrations}[$i]->{name})->from_data(
-            @{$self->migrations}[$i]->{class}, @{$self->migrations}[$i]->{name}
-        )->migrate(@{$self->migrations}[$i]->{migration});
+        if (exists @{$self->migrations}[$i]->{class}) {
+            my $cl = load_class @{$self->migrations}[$i]->{class};
+            $self->pg->migrations->name(
+                @{$self->migrations}[$i]->{name}
+            )->from_data(
+                @{$self->migrations}[$i]->{class},
+                @{$self->migrations}[$i]->{name}
+            )->migrate(
+                @{$self->migrations}[$i]->{migration}
+            );
+        } elsif (exists @{$self->migrations}[$i]->{file}) {
+            $self->pg->migrations->name(
+                @{$self->migrations}[$i]->{name}
+            )->from_file(
+                @{$self->migrations}[$i]->{file}
+            )->migrate(
+                @{$self->migrations}[$i]->{migration}
+            );
+        }
     }
 
     return 1;
@@ -179,6 +196,7 @@ __END__
 
 
 
+
 #################### pod generated by Pod::Autopod - keep this line to make pod updates possible ####################
 
 =head1 NAME
@@ -195,6 +213,8 @@ Daje::Workflow::Database - It's the database migrate plugin for Daje::Workflow
 
    push @{$migrations}, {class => 'Daje::Workflow::Database', name => 'workflow', migration => 2};
 
+   push @{$migrations}, {file => '/home/user/schema/users.sql', name => 'users'};
+
    Daje::Workflow::Database->new(
         pg            => $pg,
         migrations    => $migrations,
